/******************************************************************************/
/*                  S A S   S A M P L E   L I B R A R Y                       */
/*                                                                            */
/*    NAME: fcf_alert_investigation_extract.sas                               */
/*   TITLE: fcf_alert_investigation_extract                                   */
/* PRODUCT: SAS Anti-Money Laundering                                         */
/*  SYSTEM: UNIX/WINDOWS                                                      */
/******************************************************************************/

/* ************************************************************************** */
/*  Copyright (c) 2016 by SAS Institute Inc., Cary, NC 27513 USA              */
/*  ---All Rights Reserved.                                                   */
/* ************************************************************************** */
/*---------------------------------------------------------
 *  Host and Site specific customizations may be REQUIRED
 *---------------------------------------------------------*/

%macro fcf_alert_investigation_extract;

/*----------------------------------------------------------------------------*/
/* Configurable macro variable for unassinged alerts.
/*----------------------------------------------------------------------------*/
  %let NO_OWNER = No Owner;

/*----------------------------------------------------------------------------*/ 
/* Configurable macro variables 
/* - FCF_CONFIG_LOCALE_OPT: macro variable to override FCF_CONFIG_LOCALE.
/*----------------------------------------------------------------------------*/ 

  %let FCF_CONFIG_LOCALE_OPT = %sysfunc(sasmsg(sashelp.fcflocale,&fcf_config_locale, N));


/*----------------------------------------------------------------------------*/
/* Set error code to 0 and message to blank
/*----------------------------------------------------------------------------*/
  %let trans_rc = 0;
  %let _fcfmsg_=;

/*----------------------------------------------------------------------------*/
/* Retrieve all AML Alerts from &seg_kc_libname..FSK_ALERT.
/*----------------------------------------------------------------------------*/
    %if %sysfunc(exist(&seg_kc_libname..FSK_ALERT)) and %sysfunc(exist(&seg_kc_libname..FSK_ALERT_CASE)) %then %do;
        proc sql;
              create table selected_alerts as
              select a.ALERT_ID,
                     a.PRIMARY_ENTITY_LEVEL_CODE, 
                     a.PRIMARY_ENTITY_NAME, 
                     a.PRIMARY_ENTITY_NUMBER, 
                     a.SCENARIO_NAME, 
                     a.ACTUAL_VALUES_TEXT, 
                     a.ALERT_DESCRIPTION, 
                     a.MONEY_LAUNDERING_RISK_SCORE, 
                     a.TERROR_FINANCING_RISK_SCORE, 
                     a.ALERT_STATUS_CODE, 
                     a.RUN_DATE, 
                     '' as INCIDENT_RK,
                     a.SCENARIO_ID,
                     .  as VALID_from_DTTM,  
                     .  as VALID_TO_DTTM,
                     '' as CASE_RK,
                      '' as INCIDENT_ID,
                     '' as SOURCE_SYSTEM_CD,
                     '' as INCIDENT_TYPE_CD,
                     '' as INCIDENT_CATEGORY_CD label='INCIDENT_CATEGORY_CD',
                     '' as INCIDENT_SUBCATEGORY_CD label='INCIDENT_SUBCATEGORY_CD',
                     '' as INCIDENT_DESC,
                     .  as INCIDENT_from_DT,
                     .  as INCIDENT_from_TM,
                     .  as INCIDENT_TO_DT,
                     .  as INCIDENT_TO_TM,
                     .  as DETECTION_DT,
                     .  as DETECTION_TM,
                     .  as NOTIFICATION_DT,
                     .  as NOTIFICATION_TM,
                     '' as UI_DEF_FILE_NM,
                     a.CREATE_USER_ID,
                     /* derive YEAR from CREATE_DATE */
                     YEAR(datepart(a.CREATE_DATE)) as YEAR, 
                     /* derive QUARTER from CREATE_DATE */
                     left(put(datepart(a.CREATE_DATE),yyq10.)) as QUARTER,
                     /* derive Month from CREATE_DATE */
                     datepart(a.CREATE_DATE) as MONTH format monyy7.,
                     /* derive WEEK in mulitple formats for reporting display from CREATE_DATE */
                     put(datepart(a.CREATE_DATE), weeku5.) as WEEK,
                     intnx('week',datepart(a.CREATE_DATE),0) as WEEKBEGINDATE format Worddate12. ,
                     /* reformat CREATE_DATE for date calculations and display */
                     datepart(a.CREATE_DATE) format=date9. as CREATE_DTTM,
                     /* reformat CREATE_DATE for date calculations and display */
                     CASE WHEN b.ALERT_ID ^= . and a.ALERT_STATUS_CODE ^= 'ACT' then  
                      datepart(b.LSTUPDATE_DATE)  
                     ELSE . END as CLOSE_DTTM format=date9.,
                     '' as UPDATE_USER_ID, 
                     '' as VERSION_NO, 
                     '' as DELETE_FLG, 
                     '' as INVESTIGATOR_USER_ID,
                     a.ALERT_STATUS_CODE as INCIDENT_DISPOSITION_CD label='INCIDENT DISPOSITION CD',
                     '' as INCIDENT_STATUS_CD
              from   &seg_kc_libname..FSK_ALERT as a left join &seg_kc_libname..FSK_ALERT_CASE as b
                     on a.ALERT_ID = b.ALERT_ID;
              quit;
  %end;
  %else %do;
      %let trans_rc = 900;
      %let _fcfmsg_ = required &seg_kc_libname..FSK_alert or &seg_kc_libname..FSK_alert_case table not found, processing will end;  
      %fcf_put_error;
      %goto MACRO_END;
  %end;
/*----------------------------------------------------------------------------*/
/* Append Scenario related info.
/*----------------------------------------------------------------------------*/
    %if %sysfunc(exist(&seg_kc_libname..FSK_SCENARIO)) %then %do;
        proc sql nowarn;
        create table selected_alerts as
              select a.ALERT_ID,
                     a.PRIMARY_ENTITY_LEVEL_CODE, 
                     a.PRIMARY_ENTITY_NAME, 
                     a.PRIMARY_ENTITY_NUMBER, 
                     a.SCENARIO_NAME, 
                     a.ACTUAL_VALUES_TEXT, 
                     a.ALERT_DESCRIPTION, 
                     a.MONEY_LAUNDERING_RISK_SCORE, 
                     a.TERROR_FINANCING_RISK_SCORE, 
                     a.ALERT_STATUS_CODE, 
                     a.RUN_DATE, 
                     a.INCIDENT_RK,
                     a.SCENARIO_ID,
                     a.VALID_from_DTTM,  
                     a.VALID_TO_DTTM,
                     a.CASE_RK,
                     a.INCIDENT_ID,
                     a.SOURCE_SYSTEM_CD,
                     a.INCIDENT_TYPE_CD,
                     b.SCENARIO_CATEGORY_CODE as INCIDENT_CATEGORY_CD label='INCIDENT_CATEGORY_CD',
                     a.INCIDENT_SUBCATEGORY_CD label='INCIDENT_SUBCATEGORY_CD',
                     a.INCIDENT_DESC,
                     a.INCIDENT_from_DT,
                     a.INCIDENT_from_TM,
                     a.INCIDENT_TO_DT,
                     a.INCIDENT_TO_TM,
                     a.DETECTION_DT,
                     a.DETECTION_TM,
                     a.NOTIFICATION_DT,
                     a.NOTIFICATION_TM,
                     a.UI_DEF_FILE_NM,
                     a.CREATE_USER_ID,
                     a.YEAR, 
                     a.QUARTER,
                     a.MONTH,
                     a.WEEK,
                     a.WEEKBEGINDATE,
                     a.CREATE_DTTM,
                     a.CLOSE_DTTM,
                     a.UPDATE_USER_ID, 
                     a.VERSION_NO, 
                     a.DELETE_FLG, 
                     a.INVESTIGATOR_USER_ID,
                     a.INCIDENT_DISPOSITION_CD,
                     a.INCIDENT_STATUS_CD
              from   selected_alerts as a, &seg_kc_libname..FSK_SCENARIO as b
                     where a.SCENARIO_ID = b.SCENARIO_ID;
              quit;
  %end;
  %else %do;
      %let trans_rc = 900;
      %let _fcfmsg_ = required &seg_kc_libname..FSK_scenario table not found, processing will end;  
      %fcf_put_error;
      %goto MACRO_END;
  %end;

/*----------------------------------------------------------------------------*/
/* Determine earliest date, total number of weeks and weeks span into 
/* macro varibles minDate, nbrWeeks and weekDelta respectively from
/* selected alerts.
/*----------------------------------------------------------------------------*/

  proc sql noprint;
      select min(create_dttm) into :minDate from selected_alerts;
      select count(distinct(week)) into :nbrWeeks from selected_alerts;
      select intck('week',minDate,today())+1 into :weekDelta
         from (select min(create_dttm) as minDate 
               from selected_alerts);
  quit;

/*----------------------------------------------------------------------------*/
/* Create Age groups buckets and logic to bucket selected alerts accordingly
/* from macro varibles minDate, nbrWeeks and weekDelta.
/*----------------------------------------------------------------------------*/

 %let DaysInPeriod = 7;
 DATA alert_age_range_list;
    length AGE_GRP_IN_DAYS $9. AGEGRPCHECK $250.;
    WEEK_NBR=1;
    tmpDate = &minDate + ((&weekDelta-1) * 7);
    START = 0;
    END = &DaysInPeriod - 1;
    AGE_GRP_PAD  = 4;
    AGEGRPCHECK = ' ALERT_AGE GE ' || trim(left(put(START,8.))) || ' and  ALERT_AGE LE ' || trim(left(put(END,8.)));
    AGE_GRP_IN_DAYS = '    ' || trim(left(put(START,8.))) || '-' || trim(left(put(END,8.)));
    output;

    do WEEK_NBR= 2 to &weekDelta;
        tmpDate = &minDate + ((&weekDelta- WEEK_NBR) * 7);
        START = END + 1;
        END = START + &DaysInPeriod - 1;
        AGEGRPCHECK = ' ALERT_AGE>= ' || trim(left(put(START,8.))) || ' and  ALERT_AGE=< ' || trim(left(put(END,8.)));
        /* single digits - pad with 4 spaces for VA .....#-# */
        if  START < 10 then do; 
           AGE_GRP_PAD  = 4;
           AGE_GRP_IN_DAYS = '    ' || trim(left(put(START,8.))) || '-' || trim(left(put(END,8.)));
        end;
        /* double digits - pad with 3 places for VA ...##-## */
        if START > 9 and START < 100 then do;
           AGE_GRP_PAD  = 3;  
           AGE_GRP_IN_DAYS = '   ' || trim(left(put(START,8.))) || '-' || trim(left(put(END,8.)));
        end;
        /* triple digits - pad with 1 places for VA .###-### */
        if START > 99 and START < 1000 then do; 
           AGE_GRP_PAD  = 2;
           AGE_GRP_IN_DAYS = ' ' ||trim(left(put(START,8.))) || '-' || trim(left(put(END,8.)));
        end;
        /* quad digits - no pad  ####-#### */
        if START > 1000 then do;
           AGE_GRP_PAD  = 0;
           AGE_GRP_IN_DAYS = trim(left(put(START,8.))) || '-' || trim(left(put(END,8.)));
        end;
        output;
    end;
    run;

/*----------------------------------------------------------------------------*/
/* Select Age groups, logic, number of padding spaces for VA and week number
/* into dynamic macro variable ranges:
/*             :ageGrp1 - :ageGrp%trim(&nbrAgeBuckets)
/*             :ageChk1 - :ageChk%trim(&nbrAgeBuckets)
/*             :agePad1 - :agePad%trim(&nbrAgeBuckets)
/*             :ageWeek1 - :ageWeek%trim(&nbrAgeBuckets)
/* from alert_age_range_list
/*----------------------------------------------------------------------------*/
    proc sql noprint;
        select count(*) into :nbrAgeBuckets from alert_age_range_list;
        select AGE_GRP_IN_DAYS, AGEGRPCHECK, AGE_GRP_PAD , WEEK_NBR
                         into :ageGrp1 - :ageGrp%trim(&nbrAgeBuckets),
                              :ageChk1 - :ageChk%trim(&nbrAgeBuckets),
                              :agePad1 - :agePad%trim(&nbrAgeBuckets),
                              :ageWeek1 - :ageWeek%trim(&nbrAgeBuckets)
        from alert_age_range_list;
    quit;
 
/*----------------------------------------------------------------------------*/
/* Bucket alerts into age grous (number of days old range)
/*----------------------------------------------------------------------------*/

    data selected_alerts;
      set selected_alerts;
      length AGE_GRP_IN_DAYS $9.;
      
      if INCIDENT_DISPOSITION_CD = 'ACT' then do; 
           ALERT_AGE= today() - create_dttm;
           DURATION = ALERT_AGE;
      end;
      else do;
           ALERT_AGE = .;
           DURATION = close_dttm - create_dttm;
      end;
      /* Leverage dynamic marco ranges to generate code for age bucketing */
      %do i = 1 %to &nbrAgeBuckets;
          if (&&ageChk&i) then do;
              AGE_GRP_IN_DAYS = 
              %if &&agePad&i > 0 %then %do;
                   %do p = 1 %to &&agePad&i;
                      ' ' || 
                   %end;
              %end;
               "&&ageGrp&i";
               WEEK_NBR= &&ageWeek&i;
          end;
      %end;
    run;
    
/*----------------------------------------------------------------------------*/
/* Summarize at the incident_disposition_cd, incident_category_cd level
/* to determine number of alerts, average age and maximum age per classification
/*----------------------------------------------------------------------------*/

  proc summary data=selected_alerts nway;
  class incident_disposition_cd incident_category_cd;
  var ALERT_AGE DURATION;
  output  out=ALERTS_SUMMARY
            n(DURATION) =   NUM_ALERTS
            mean(ALERT_AGE) = AVG_AGE
            max(ALERT_AGE) = MAX_AGE 
            mean(DURATION) = AVG_DURATION
            max(DURATION) = MAX_DURATION;
  run;

/*----------------------------------------------------------------------------*/
/* Join number of alerts, average age and maximum age per classification
/* to selected alerts.
/* Note: Leverage proc sql nowarn option to suppress: 
/*    WARNING: This CREATE TABLE statement recursively references the target table
/*----------------------------------------------------------------------------*/ 
   proc sql nowarn;
      create table work.selected_alerts as
           select a.ALERT_ID,
                     a.PRIMARY_ENTITY_LEVEL_CODE, 
                     a.PRIMARY_ENTITY_NAME, 
                     a.PRIMARY_ENTITY_NUMBER, 
                     a.SCENARIO_NAME, 
                     a.ACTUAL_VALUES_TEXT, 
                     a.ALERT_DESCRIPTION, 
                     a.MONEY_LAUNDERING_RISK_SCORE, 
                     a.TERROR_FINANCING_RISK_SCORE, 
                     a.ALERT_STATUS_CODE, 
                     a.RUN_DATE, 
                     a.INCIDENT_RK,
                     a.SCENARIO_ID,
                     a.VALID_from_DTTM,  
                     a.VALID_TO_DTTM,
                     a.CASE_RK,
                     a.INCIDENT_ID,
                     a.SOURCE_SYSTEM_CD,
                     a.INCIDENT_TYPE_CD,
                     a.INCIDENT_CATEGORY_CD,
                     a.INCIDENT_SUBCATEGORY_CD label='INCIDENT_SUBCATEGORY_CD',
                     a.INCIDENT_DESC,
                     a.INCIDENT_from_DT,
                     a.INCIDENT_from_TM,
                     a.INCIDENT_TO_DT,
                     a.INCIDENT_TO_TM,
                     a.DETECTION_DT,
                     a.DETECTION_TM,
                     a.NOTIFICATION_DT,
                     a.NOTIFICATION_TM,
                     a.UI_DEF_FILE_NM,
                     a.CREATE_USER_ID,
                     a.YEAR, 
                     a.QUARTER,
                     a.MONTH,
                     a.AGE_GRP_IN_DAYS,
                     a.WEEK,
                     a.WEEK_NBR,
                     a.WEEKBEGINDATE,
                     a.CREATE_DTTM,
                     a.CLOSE_DTTM,
                     a.UPDATE_USER_ID, 
                     a.VERSION_NO, 
                     a.DELETE_FLG, 
                     a.INVESTIGATOR_USER_ID,
                     a.INCIDENT_DISPOSITION_CD,
                     a.INCIDENT_STATUS_CD,
                     a.ALERT_AGE,
                     a.DURATION,
                     b.NUM_ALERTS as CAT_NUM_ALERTS,
                     b.MAX_AGE,
                     b.AVG_AGE format 8.2,
                     b.MAX_DURATION ,
                     b.AVG_DURATION format 8.2
     from selected_alerts a, ALERTS_SUMMARY b
     where a.INCIDENT_DISPOSITION_CD = b.INCIDENT_DISPOSITION_CD and        
            a.INCIDENT_CATEGORY_CD = b.INCIDENT_CATEGORY_CD;
  quit;

/*----------------------------------------------------------------------------*/
/* Select Summary of number of alerts (NUM_ALERTS) into macro variables by 
/* alert disposition for VA report display
/*       :totalACT, totalCLS, totalSUP
/* from ALERTS_SUMMARY
/*----------------------------------------------------------------------------*/   
  proc sql noprint;
      select sum(NUM_ALERTS) into :totalACT 
          from ALERTS_SUMMARY 
          where INCIDENT_DISPOSITION_CD = 'ACT';
      select sum(NUM_ALERTS) into :totalCLC  
          from ALERTS_SUMMARY 
          where INCIDENT_DISPOSITION_CD = 'CLC';
      select sum(NUM_ALERTS) into :totalCLS  
          from ALERTS_SUMMARY 
          where INCIDENT_DISPOSITION_CD = 'CLS';
      select sum(NUM_ALERTS) into :totalSUP
          from ALERTS_SUMMARY 
          where INCIDENT_DISPOSITION_CD = 'SUP';
   quit;

/*----------------------------------------------------------------------------*/
/* Build Duration Display column for Duration of All Alerts report 
/*----------------------------------------------------------------------------*/

  data selected_alerts;
      set work.selected_alerts;
      length DURATION_DISPLAY $60.;
      select (INCIDENT_DISPOSITION_CD);
          when ('ACT') do; 
                DURATION_DISPLAY = 'Days Active (Number of active alerts = ' || trim(left(&totalACT)) || ')';
          end;
          when ('CLC') do; 
                DURATION_DISPLAY = 'Days to Close (Number of alerts added to case (closed) = ' || trim(left(&totalCLC)) || ')';
          end;
          when ('CLS') do; 
                DURATION_DISPLAY = 'Days to Close (Number of closed alerts = ' || trim(left(&totalCLS)) || ')';
          end;
          otherwise do; 
                DURATION_DISPLAY = 'Days to Suppress (Number of suppressed alerts = ' || trim(left(&totalSUP)) ||')';
          end;
      end;
  run;

/*----------------------------------------------------------------------------*/
/* Get long display values INCIDENT_DISPOSITION_CD, INCIDENT_CATEGORY_CD
/* and INCIDENT_SUBCATEGORY_CD.
/*----------------------------------------------------------------------------*/
  %if %sysfunc(exist(&seg_kc_libname..FSK_LOV)) %then %do;

        data RT_ALERT_STATUS_DISPLAY (keep= LOV_TYPE_CODE LOV_TYPE_DESC rename=(LOV_TYPE_CODE = value_cd LOV_TYPE_DESC = value_desc ))
             RT_INCIDENT_CATEGORY_DISPLAY (keep= LOV_TYPE_CODE LOV_TYPE_DESC rename=(LOV_TYPE_CODE = value_cd LOV_TYPE_DESC = value_desc ));
        set &seg_kc_libname..FSK_LOV;
             if LOV_TYPE_NAME = 'RT_ALERT_STATUS' and LOV_LANGUAGE_DESC = "&FCF_CONFIG_LOCALE_OPT" then output RT_ALERT_STATUS_DISPLAY;
             if LOV_TYPE_NAME = 'SCENARIO_CATEGORY' and LOV_LANGUAGE_DESC = "&FCF_CONFIG_LOCALE_OPT" then output RT_INCIDENT_CATEGORY_DISPLAY;
        run;

        /*----------------------------------------------------------------------------*/
        /* Update incident_disposition_cd  
        /*----------------------------------------------------------------------------*/
        %fcf_update_display_data(tabName=selected_alerts,
                       LUTAB=RT_ALERT_STATUS_DISPLAY,
                       existCol=INCIDENT_DISPOSITION_CD,
                       LUKey=VALUE_CD,
                       LUVal=VALUE_DESC
                       );
        /*----------------------------------------------------------------------------*/
        /* Update incident_category_cd  
        /*----------------------------------------------------------------------------*/
        %fcf_update_display_data(tabName=selected_alerts,
                       LUTAB=RT_INCIDENT_CATEGORY_DISPLAY,
                       existCol=INCIDENT_CATEGORY_CD,
                       LUKey=VALUE_CD,
                       LUVal=VALUE_DESC
                       );     
        /*----------------------------------------------------------------------------*/
        /* Build dynamic in clause for display data retrieval.
        /*----------------------------------------------------------------------------*/
        PROC SQL noprint;
            select "'" || PRIMARY_ENTITY_LEVEL_CODE || "'" into :entityInClauseCond separated by ", " from
            (select distinct PRIMARY_ENTITY_LEVEL_CODE from selected_alerts);
        quit;
        %fcf_rcset(&sqlrc);
        %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
            %let _fcfmsg_=ERROR: Unable to build sql clause, processing will end.;
            %fcf_put_error;
            %goto MACRO_END;
        %end;
   /*----------------------------------------------------------------------------*/
   /* Get long display values for ENTITY_LEVEL_CODE
   /*----------------------------------------------------------------------------*/
    proc sql;
        create table ENTITY_LEVEL_CODE_DISPLAY as
            select distinct LOV_TYPE_CODE as value_cd, LOV_TYPE_DESC as value_desc from &seg_kc_libname..FSK_LOV
                where LOV_TYPE_NAME = 'RT_ENTITY_LEVEL' and
                      LOV_LANGUAGE_DESC = "&fcf_config_locale_opt" and
                      VALUE_CD IN (&entityInClauseCond);
    quit;

    %fcf_rcset(&sqlrc);
    %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
        %let _fcfmsg_=ERROR: Unable to create table ENTITY_LEVEL_CODE_DISPLAY, processing will end;
        %fcf_put_error;
        %goto MACRO_END;
    %end;
   /*----------------------------------------------------------------------------*/
   /* Verify at least one entity level display code returned.
   /*----------------------------------------------------------------------------*/
    %let dsid = %sysfunc(open(ENTITY_LEVEL_CODE_DISPLAY));
    %if %sysfunc(attrn(&dsid, nlobs)) > 0 %then %do;
        %let rc = %sysfunc(close(&dsid));
   /*----------------------------------------------------------------------------*/
   /* Update ENTITY_LEVEL_CODE  
   /*----------------------------------------------------------------------------*/
        %fcf_update_display_data(tabName=selected_alerts,
            LUTAB=ENTITY_LEVEL_CODE_DISPLAY,
            existCol=PRIMARY_ENTITY_LEVEL_CODE,
            LUKey=VALUE_CD,
            LUVal=VALUE_DESC
            );
    %end;
    %else %do;
      %let trans_rc = 909;
      %let _fcfmsg_ = ERROR: No Entity Level Display Codes returned.;  
      %fcf_put_error;
      %goto MACRO_END;
    %end; 
  %end; 
  %else %do;
          %let _fcfmsg_ = WARNNG: &seg_kc_libname..FSK_lov table not found codes will be displayed in report.;  
          %fcf_put_error;
  %end;

/*----------------------------------------------------------------------------*/
/* Get current users from metadata.
/*----------------------------------------------------------------------------*/
  %mduextr(libref=work);
   
/*----------------------------------------------------------------------------*/
/* GET CURRENT OWNER OF ALERT DISPLAY NAME
/*----------------------------------------------------------------------------*/
  %if %sysfunc(exist(work.person)) %then %do;
      proc sql;
      create table fcf_rpt.ALERT_INVESTIGATION_EXTRACT as
      select a.ALERT_ID, 
             a.PRIMARY_ENTITY_LEVEL_CODE, 
             a.PRIMARY_ENTITY_NAME, 
             a.PRIMARY_ENTITY_NUMBER, 
             a.SCENARIO_NAME, 
             a.ACTUAL_VALUES_TEXT, 
             a.ALERT_DESCRIPTION, 
             a.MONEY_LAUNDERING_RISK_SCORE, 
             a.TERROR_FINANCING_RISK_SCORE, 
             a.ALERT_STATUS_CODE,
             a.RUN_DATE, 
             a.CREATE_DTTM, 
             a.INCIDENT_RK, 
             a.SCENARIO_ID, 
             a.INVESTIGATOR_USER_ID,
             a.VALID_from_DTTM, 
             a.VALID_TO_DTTM, 
             a.CASE_RK, 
             a.INCIDENT_ID, 
             a.SOURCE_SYSTEM_CD, 
             a.INCIDENT_TYPE_CD, 
             a.INCIDENT_CATEGORY_CD, 
             a.INCIDENT_SUBCATEGORY_CD, 
             a.INCIDENT_DESC, 
             a.INCIDENT_from_DT, 
             a.INCIDENT_from_TM, 
             a.INCIDENT_TO_DT, 
             a.INCIDENT_TO_TM, 
             a.DETECTION_DT, 
             a.DETECTION_TM, 
             a.NOTIFICATION_DT, 
             a.NOTIFICATION_TM, 
             a.UI_DEF_FILE_NM, 
             a.CREATE_USER_ID,
             a.WEEK, 
             a.WEEK_NBR, 
             a.WEEKBEGINDATE, 
             a.YEAR,
             a.QUARTER, 
             a.MONTH, 
             a.AGE_GRP_IN_DAYS,
             a.UPDATE_USER_ID, 
             a.VERSION_NO, 
             a.DELETE_FLG, 
             CASE WHEN  b.NAME ^= "" THEN b.DISPLAYNAME 
             ELSE "&no_owner" END AS OWNER,
             a.INCIDENT_DISPOSITION_CD, 
             a.CLOSE_DTTM, 
             a.INCIDENT_STATUS_CD, 
             a.DURATION_DISPLAY, 
             a.CAT_NUM_ALERTS, 
             a.ALERT_AGE,
             a.DURATION, 
             a.MAX_AGE, 
             a.AVG_AGE,
             a.MAX_DURATION,
             a.AVG_DURATION
      from SELECTED_ALERTS as a
      left join PERSON as b ON (a.INVESTIGATOR_USER_ID = b.NAME);
      quit;
  %end;
  %else %do;
        %let trans_rc = 900;
        %let _fcfmsg_ =ERROR: work.person table not found, processing will end;  
        %fcf_put_error;
        %goto MACRO_END;
  %end;

%MACRO_END:

%if &trans_rc in (3 5 900 909) %then
     %fcf_execute_macro(fcf_error);
%else %do;
     %fcf_execute_macro(fcf_success);
%end;

%mend fcf_alert_investigation_extract;
